@@ -12,7 +12,7 @@ class globalValues:
         """
 
         self.config = None
-        """ ログファイル名 """
+        """ 共通設定 """
 
         self.platForm = self.platFormStruct()
         """ プラットフォーム構造体 """
